<?php

namespace Drupal\linkpurpose\Form;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class to define all settings of the module.
 */
class LinkpurposeSettings extends ConfigFormBase
{

    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'linkpurpose_form_settings';
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames()
    {
        return [
        'linkpurpose.settings',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
        $config = $this->config('linkpurpose.settings');
        $permissions = Url::fromRoute('user.admin_permissions');

        $form['base'] = [
            '#type' => 'fieldset',
            '#title' => t('Basic configuration'),
        ];

        $form['base']['text'] = [
            '#markup' => '
            <p>Most sites only need to define their domain:</p>',
        ];

        $form['base']['domain'] = [
            '#title' => $this->t("Additional domains to consider internal in absolute URLs"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => empty($config->get('domain')) ? $GLOBALS['base_url'] : $config->get('domain'),
            '#description' => $this->t('The current active domain is always considered internal.<br>Provide a comma separated list of domains, optionally including protocols, trailing paths, subdomains or * as a leading subdomain wildcard:<br>
            e.g.: <code><em>www.only-www.net, *.all-subdomains.net, a-shared-site.net/just-my-blog</em></code>'),
            '#default_value' => $config->get('domain'),
        ];

        $form['migrating'] = [
            '#type' => 'details',
            '#title' => $this->t('Tips for migrating from ExtLink'),
        ];

        $form['migrating']['extlink'] = [
            '#markup' => '<p>If you are migrating from ExtLink and need near-identical markup to match a theme\'s existing CSS:</p>
                         <ol>
                            <li>Install <a href="https://www.drupal.org/project/fontawesome">FontAwesome</a>. Even if you were not using FontAwesome with ExtLink, it will help you mimic its markup.</li>
                            <li>Customize the <a href="#edit-external">external and mailto links</a> to use the "Classes" type.</li>
                            <li>For External Links, set "class added to the &lt;a&gt; tag" to <code><em>ext</em></code>, and add <code><em>ext</em></code> to "icon classes"</li>
                            <li>For Mailto links, set "class added to the &lt;a&gt; tag" to <code><em>mailto</em></code>, and add <code><em>mailto</em></code> to "icon classes"</li>
                            <li><strong>If you were using SVG icons</strong> in ExtLink, set FontAwesome to embed icons using "SVG with JS." Otherwise leave your settings as-is.</li>
                         </ol>',
        ];

        
        /*
            Base fieldset.
        */
        $form['containers'] = [
            '#type' => 'details',
            '#title' => t('Inclusions & exclusions'),
        ];

        $form['containers']['text'] = [
            '#markup' => '<p><strong>Provide valid <a target="_blank" href="https://developer.mozilla.org/en-US/docs/Learn/CSS/Building_blocks/Selectors">CSS selectors</a> for each of the fields in this section.</strong>
            <br>Comma separate selector lists: <code><em>.this, #that, [data-this="that"]</em></code></p>',
        ];

        $form['containers']['roots'] = [
            '#title' => $this->t("Page areas to check"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#description' => $this->t('E.g.: <code><em>main, #footer</em></code>'),
            '#default_value' => $config->get('roots'),
        ];

        $form['containers']['hideIcon'] = [
            '#title' => $this->t("Do not display the icon on these links"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#description' => $this->t(
                'This module inserts two elements: an icon, and <strong>visually-hidden hint text</strong> for screen readers. 
                <br>When visual context makes the link\'s purpose visually obvious, the icon can be visibly hidden using this setting<br>
                Note that this can also be done in CSS: <code><em>.fancy-card .link-purpose-icon { display: none; }</em></code>'),
            '#default_value' => $config->get('hideIcon'),
            ];
        
        $form['containers']['ignore'] = [
            '#title' => $this->t("Ignore these links entirely"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#description' => $this->t(
                'Only use when machine-readable context or the text of the link itself makes the text of the screen reader hint redundant.<br>
                E.g.: <code><em>#external-links-list a, .in-the-news a</em></code>.'
            ),
            '#default_value' => $config->get('ignore'),
            ];

        $form['containers']['shadowComponents'] = [
            '#title' => $this->t("Mark links inside this shadow DOM"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#description' => $this->t('<em>Most sites do not have Web components and can ignore this setting.</em><br>E.g.: <code><em>custom-tag-tab-widget, .shadow-embed</em></code>'),
            '#default_value' => $config->get('shadowComponents'),
        ];

        $form['containers']['noRunIfPresent'] = [
            '#title' => $this->t("Do not mark any links if elements are detected"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#description' => $this->t('Disables module on page.<br>Default: <code><em>.ck-editor, #quickedit-entity-toolbar, .layout-builder-form</em></code>'),
            '#default_value' => $config->get('noRunIfPresent'),
        ];

        $form['containers']['noRunIfAbsent'] = [
            '#title' => $this->t("Do not mark any links if elements are absent"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#default_value' => $config->get('noRunIfAbsent'),
        ];

        $form['containers']['themePreprocess'] = [
            '#title' => $this->t("Do not mark ANY links"),
            '#type' => 'checkbox',
            '#placeholder' => '',
            '#description' => $this->t('Set if you want to preprocess the options object in theme or module JS, e.g. to add additional link categories or use custom SVG icons.<br>
            Your theme will need a customized copy of <em>linkpurpose-drupal.js</em> to process <em>drupalSettings.linkPurpose</em> and initialize the library.'),
            '#default_value' => $config->get('themePreprocess'),
        ];

        /*
            Icons fieldset.
        */
        $form['icons'] = [
            '#type' => 'fieldset',
            '#title' => t('Customize icons'),
        ];
        
        $form['icons']['text'] = [
            '#markup' => 'See the <a href="https://github.com/itmaybejj/linkpurpose" target="_blank">Library docs</a> for output examples.',
        ];

        /*
            External Link Icons.
        */

        $form['icons']['external'] = [
            '#type' => 'details',
            '#title' => $this->t('External Link Icons'),
        ];

        $form['icons']['external']['purposeExternalNoReferrer'] = [
            '#title' => $this->t("External links: add noreferrer attribute"),
            '#type' => 'checkbox',
            '#default_value' => $config->get('purposeExternalNoReferrer'),
        ];
        $form['icons']['external']['purposeExternalNewWindow'] = [
            '#title' => $this->t("External links: open in new window"),
            '#type' => 'checkbox',
            '#default_value' => $config->get('purposeExternalNewWindow'),
        ];

        $form['icons']['external']['purposeExternalIconType'] = [
            '#title' => $this->t("External links: icon type"),
            '#type' => 'select',
            '#options' => [
                'html' => $this->t('SVG (default)'),
                'classes' => $this->t('Classes (e.g., FontAwesome)'),
            ],
            '#default_value' => $config->get('purposeExternalIconType'),
            ];
        
        $form['icons']['external']['purposeExternalIconClasses'] = [
            '#title' => $this->t("External links: icon classes"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => 'fa-solid, fa-up-right-from-square',
            '#description' => $this->t('Separate multiple classes with commas. Default: <a href="https://fontawesome.com/icons/arrow-up-right-from-square">fa-solid, fa-arrow-up-right-from-square</a>'),
            '#default_value' => $config->get('purposeExternalIconClasses'),
            '#states' => [
                'visible' => [
                  // Enable only when type is classes.
                  ':input[id="edit-purposeexternalicontype"]' => ['value' => 'classes'],
                ],
              ],
        ];

        $form['icons']['external']['purposeExternalIconPosition'] = [
            '#title' => $this->t("External links: icon position"),
            '#type' => 'select',
            '#options' => [
                'beforeend' => $this->t('Append (default)'),
                'beforebegin' => $this->t('Before'),
                'afterbegin' => $this->t('Prepend'),
                'afterend' => $this->t('After'),
            ],
            '#default_value' => $config->get('purposeExternalIconPosition'),
            ];

        $form['icons']['external']['purposeExternalMessage'] = [
            '#title' => $this->t("External links: hidden text for screen readers"),
            '#type' => 'textfield',
            '#placeholder' => '(Link is external)',
            '#default_value' => $config->get('purposeExternalMessage'),
        ];

        $form['icons']['external']['purposeExternalClass'] = [
            '#title' => $this->t("External links: class added to the &lt;a&gt; tag"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-external',
            '#default_value' => $config->get('purposeExternalClass'),
        ];

        $form['icons']['external']['purposeExternalIconWrapperClass'] = [
            '#title' => $this->t("External links: class added to icon wrapper &lt;span&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-external-icon',
            '#default_value' => $config->get('purposeExternalIconWrapperClass'),
        ];

        $form['icons']['external']['purposeExternalSelector'] = [
            '#title' => $this->t("External links: selectors for additional links to consider external"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => 'Most sites can ignore this...',
            '#default_value' => $config->get('purposeExternalSelector'),
            '#description' => 'Used for links that have internal HREF attributes, but should be flagged as external anyway.<br>
            Provide a complete CSS selector; be as fancy as you need.<br>
            E.g.: <code><em>.in-the-news a, [href^="https://that-one-subdomain"</em></code>'
        ];

        /*
            Document Icons.
        */

        $form['icons']['document'] = [
            '#type' => 'details',
            '#title' => $this->t('Document Icons'),
        ];

        $form['icons']['document']['purposeDocumentIconType'] = [
            '#title' => $this->t("Documents: icon type"),
            '#type' => 'select',
            '#options' => [
                'html' => $this->t('SVG (default)'),
                'classes' => $this->t('Classes (e.g., FontAwesome)'),
            ],
            '#default_value' => $config->get('purposeDocumentIconType'),
            ];
        
        $form['icons']['document']['purposeDocumentIconClasses'] = [
            '#title' => $this->t("Documents: icon classes"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => 'fa-regular, fa-file-lines',
            '#description' => $this->t('Separate multiple classes with commas. Default: <a href="https://fontawesome.com/icons/file-lines?f=classic&s=regular">fa-regular, fa-file-lines</a>'),
            '#default_value' => $config->get('purposeDocumentIconClasses'),
            '#states' => [
                'visible' => [
                  // Enable only when type is classes.
                  ':input[id="edit-purposedocumenticontype"]' => ['value' => 'classes'],
                ],
              ],
        ];

        $form['icons']['document']['purposeDocumentIconPosition'] = [
            '#title' => $this->t("External links: icon position"),
            '#type' => 'select',
            '#options' => [
                'beforeend' => $this->t('Append (default)'),
                'beforebegin' => $this->t('Before'),
                'afterbegin' => $this->t('Prepend'),
                'afterend' => $this->t('After'),
            ],
            '#default_value' => $config->get('purposeDocumentIconPosition'),
            ];


        $form['icons']['document']['purposeDocumentMessage'] = [
            '#title' => $this->t("Documents: hidden text for screen readers"),
            '#type' => 'textfield',
            '#placeholder' => '(Link opens document)',
            '#default_value' => $config->get('purposeDocumentMessage'),
        ];

        $form['icons']['document']['purposeDocumentClass'] = [
            '#title' => $this->t("Documents: class added to the &lt;a&gt; tag"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-document',
            '#default_value' => $config->get('purposeDocumentClass'),
        ];

        $form['icons']['document']['purposeDocumentIconWrapperClass'] = [
            '#title' => $this->t("Documents: class added to icon wrapper &lt;span&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-document-icon',
            '#default_value' => $config->get('purposeDocumentIconWrapperClass'),
        ];

        $form['icons']['document']['purposeDocumentSelector'] = [
            '#title' => $this->t("Documents: CSS selector"),
            '#type' => 'textarea',
            '#placeholder' => "[download], [href^='/document/'], [href$='.pdf'], [href*='.pdf?'], [href$='.doc'], [href$='.docx'], [href*='.doc?'], [href*='.docx?'], [href$='.ppt'], [href$='.pptx'], [href*='.ppt?'], [href*='.pptx?'], [href^='https://docs.google']",
            '#default_value' => $config->get('purposeDocumentSelector'),
            '#description' => $this->t("Add or remove categories to flag. Separate multiple attributes with commas.<br>Default: <br><code><em>[download], [href^='/document/'], [href$='.pdf'], [href*='.pdf?'], [href$='.doc'], [href$='.docx'], [href*='.doc?'], [href*='.docx?'], [href$='.ppt'], [href$='.pptx'], [href*='.ppt?'], [href*='.pptx?'], [href^='https://docs.google']</em></code>"),
        ];

        /*
            Mailto Icons.
        */

        $form['icons']['mail'] = [
            '#type' => 'details',
            '#title' => $this->t('Email Icons'),
        ];

        $form['icons']['mail']['purposeMailIconType'] = [
            '#title' => $this->t("Email links: icon type"),
            '#type' => 'select',
            '#options' => [
                'html' => $this->t('SVG (default)'),
                'classes' => $this->t('Classes (e.g., FontAwesome)'),
            ],
            '#default_value' => $config->get('purposeMailIconType'),
            ];
        
        $form['icons']['mail']['purposeMailIconClasses'] = [
            '#title' => $this->t("Email links: icon classes"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => 'fa-solid, fa-up-right-from-square',
            '#description' => $this->t('Separate multiple classes with commas. Default: <a href="https://fontawesome.com/icons/arrow-up-right-from-square">fa-solid, fa-arrow-up-right-from-square</a>'),
            '#default_value' => $config->get('purposeMailIconClasses'),
            '#states' => [
                'visible' => [
                  // Enable only when type is classes.
                  ':input[id="edit-purposemailicontype"]' => ['value' => 'classes'],
                ],
              ],
        ];

        $form['icons']['mail']['purposeMailIconPosition'] = [
            '#title' => $this->t("Email links: icon Position"),
            '#type' => 'select',
            '#options' => [
                'beforeend' => $this->t('Append (default)'),
                'beforebegin' => $this->t('Before'),
                'afterbegin' => $this->t('Prepend'),
                'afterend' => $this->t('After'),
            ],
            '#default_value' => $config->get('purposeMailIconPosition'),
            ];
            
        $form['icons']['mail']['purposeMailMessage'] = [
            '#title' => $this->t("Email links: hidden text for screen readers"),
            '#type' => 'textfield',
            '#placeholder' => '(Link sends email)',
            '#default_value' => $config->get('purposeMailMessage'),
        ];

        $form['icons']['mail']['purposeMailClass'] = [
            '#title' => $this->t("Email links: class added to the &lt;a&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-mail',
            '#default_value' => $config->get('purposeMailClass'),
        ];

        $form['icons']['mail']['purposeMailIconWrapperClass'] = [
            '#title' => $this->t("Email links: class added to icon wrapper &lt;span&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-mail-icon',
            '#default_value' => $config->get('purposeMailIconWrapperClass'),
        ];

        

        

        

        /*
            Telephone Icons.
        */

        $form['icons']['tel'] = [
            '#type' => 'details',
            '#title' => $this->t('Phone Icons'),
        ];

        $form['icons']['tel']['purposeTelIconType'] = [
            '#title' => $this->t("Phone links: icon type"),
            '#type' => 'select',
            '#options' => [
                'html' => $this->t('SVG (default)'),
                'classes' => $this->t('Classes (e.g., FontAwesome)'),
            ],
            '#default_value' => $config->get('purposeTelIconType'),
            ];
        
        $form['icons']['tel']['purposeTelIconClasses'] = [
            '#title' => $this->t("Phone links: icon classes"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => '',
            '#description' => $this->t('Separate multiple classes with commas. Default: <a href="https://fontawesome.com/icons/square-phone">fa-solid, fa-square-phone</a>'),
            '#default_value' => $config->get('purposeTelIconClasses'),
            '#states' => [
                'visible' => [
                  // Enable only when type is classes.
                  ':input[id="edit-purposetelicontype"]' => ['value' => 'classes'],
                ],
              ],
        ];

        $form['icons']['tel']['purposeTelIconPosition'] = [
            '#title' => $this->t("Phone links: icon type"),
            '#type' => 'select',
            '#options' => [
                'beforeend' => $this->t('Append (default)'),
                'beforebegin' => $this->t('Before'),
                'afterbegin' => $this->t('Prepend'),
                'afterend' => $this->t('After'),
            ],
            '#default_value' => $config->get('purposeTelIconPosition'),
            ];

        $form['icons']['tel']['purposeTelMessage'] = [
            '#title' => $this->t("Phone links: hidden text for screen readers"),
            '#type' => 'textfield',
            '#placeholder' => '(Link opens phone)',
            '#default_value' => $config->get('purposeTelMessage'),
        ];

        $form['icons']['tel']['purposeTelClass'] = [
            '#title' => $this->t("Phone links: class added to the &lt;a&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-tel',
            '#default_value' => $config->get('purposeTelClass'),
        ];

        $form['icons']['tel']['purposeTelIconWrapperClass'] = [
            '#title' => $this->t("Phone links: class added to icon wrapper &lt;span&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-tel-icon',
            '#default_value' => $config->get('purposeTelIconWrapperClass'),
        ];


        /*
            New Window Icons.
        */

        $form['icons']['window'] = [
            '#type' => 'details',
            '#title' => $this->t('Links that open in a new window'),
        ];

        $form['icons']['window']['purposeNewWindowIconType'] = [
            '#title' => $this->t("New window links: icon type"),
            '#type' => 'select',
            '#options' => [
                'html' => $this->t('SVG (default)'),
                'classes' => $this->t('Classes (e.g., FontAwesome)'),
            ],
            '#default_value' => $config->get('purposeNewWindowIconType'),
            ];
        
        $form['icons']['window']['purposeNewWindowIconClasses'] = [
            '#title' => $this->t("New window links: icon classes"),
            '#type' => 'textarea',
            '#rows' => 1,
            '#placeholder' => 'fa-regular, fa-window-restore',
            '#description' => $this->t('Separate multiple classes with commas. Default: <a href="https://fontawesome.com/icons/window-restore?f=classic&s=regular">fa-solid, fa-arrow-up-right-from-square</a>'),
            '#default_value' => $config->get('purposeNewWindowIconClasses'),
            '#states' => [
                'visible' => [
                  // Enable only when type is classes.
                  ':input[id="edit-purposenewwindowicontype"]' => ['value' => 'classes'],
                ],
              ],
        ];

        $form['icons']['window']['purposeNewWindowIconPosition'] = [
            '#title' => $this->t("New window links: icon position"),
            '#type' => 'select',
            '#options' => [
                'beforeend' => $this->t('Append (default)'),
                'beforebegin' => $this->t('Before'),
                'afterbegin' => $this->t('Prepend'),
                'afterend' => $this->t('After'),
            ],
            '#default_value' => $config->get('purposeNewWindowIconPosition'),
            ];

        $form['icons']['window']['purposeNewWindowMessage'] = [
            '#title' => $this->t("New window links: hidden text for screen readers"),
            '#type' => 'textfield',
            '#placeholder' => '(Link opens in new window)',
            '#default_value' => $config->get('purposeNewWindowMessage'),
        ];

        $form['icons']['window']['purposeNewWindowClass'] = [
            '#title' => $this->t("New window links: class added to the &lt;a&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-window',
            '#default_value' => $config->get('purposeNewWindowClass'),
        ];

        $form['icons']['window']['purposeNewWindowIconWrapperClass'] = [
            '#title' => $this->t("New window links: class added to icon wrapper &lt;span&gt;"),
            '#type' => 'textfield',
            '#placeholder' => 'link-purpose-window-icon',
            '#default_value' => $config->get('purposeNewWindowIconWrapperClass'),
        ];

        return parent::buildForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $this->config('linkpurpose.settings')
            ->set('roots', $form_state->getValue('roots'))
            ->set('domain', $form_state->getValue('domain'))
            ->set('shadowComponents', $form_state->getValue('shadowComponents'))
            ->set('ignore', $form_state->getValue('ignore'))
            ->set('hideIcon', $form_state->getValue('hideIcon'))
            ->set('noRunIfPresent', $form_state->getValue('noRunIfPresent'))
            ->set('noRunIfAbsent', $form_state->getValue('noRunIfAbsent'))
            ->set('themePreprocess', $form_state->getValue('themePreprocess'))
            
            ->set('purposeDocumentSelector', $form_state->getValue('purposeDocumentSelector'))
            ->set('purposeDocumentMessage', $form_state->getValue('purposeDocumentMessage'))
            ->set('purposeDocumentClass', $form_state->getValue('purposeDocumentClass'))
            ->set('purposeDocumentIconWrapperClass', $form_state->getValue('purposeDocumentIconWrapperClass'))
            ->set('purposeDocumentIconType', $form_state->getValue('purposeDocumentIconType'))
            ->set('purposeDocumentIconPosition', $form_state->getValue('purposeDocumentIconPosition'))
            ->set('purposeDocumentIconClasses', $form_state->getValue('purposeDocumentIconClasses'))

            ->set('purposeMailSelector', $form_state->getValue('purposeMailSelector'))
            ->set('purposeMailMessage', $form_state->getValue('purposeMailMessage'))
            ->set('purposeMailClass', $form_state->getValue('purposeMailClass'))
            ->set('purposeMailIconWrapperClass', $form_state->getValue('purposeMailIconWrapperClass'))
            ->set('purposeMailIconType', $form_state->getValue('purposeMailIconType'))
            ->set('purposeMailIconPosition', $form_state->getValue('purposeMailIconPosition'))
            ->set('purposeMailIconClasses', $form_state->getValue('purposeMailIconClasses'))

            ->set('purposeTelSelector', $form_state->getValue('purposeTelSelector'))
            ->set('purposeTelMessage', $form_state->getValue('purposeTelMessage'))
            ->set('purposeTelClass', $form_state->getValue('purposeTelClass'))
            ->set('purposeTelIconWrapperClass', $form_state->getValue('purposeTelIconWrapperClass'))
            ->set('purposeTelIconType', $form_state->getValue('purposeTelIconType'))
            ->set('purposeTelIconPosition', $form_state->getValue('purposeTelIconPosition'))
            ->set('purposeTelIconClasses', $form_state->getValue('purposeTelIconClasses'))

            ->set('purposeNewWindowSelector', $form_state->getValue('purposeNewWindowSelector'))
            ->set('purposeNewWindowMessage', $form_state->getValue('purposeNewWindowMessage'))
            ->set('purposeNewWindowClass', $form_state->getValue('purposeNewWindowClass'))
            ->set('purposeNewWindowIconWrapperClass', $form_state->getValue('purposeNewWindowIconWrapperClass'))
            ->set('purposeNewWindowIconType', $form_state->getValue('purposeNewWindowIconType'))
            ->set('purposeNewWindowIconPosition', $form_state->getValue('purposeNewWindowIconPosition'))
            ->set('purposeNewWindowIconClasses', $form_state->getValue('purposeNewWindowIconClasses'))

            ->set('purposeExternalSelector', $form_state->getValue('purposeExternalSelector'))
            ->set('purposeExternalMessage', $form_state->getValue('purposeExternalMessage'))
            ->set('purposeExternalClass', $form_state->getValue('purposeExternalClass'))
            ->set('purposeExternalNoReferrer', $form_state->getValue('purposeExternalNoReferrer'))
            ->set('purposeExternalNewWindow', $form_state->getValue('purposeExternalNewWindow'))
            ->set('purposeExternalIconWrapperClass', $form_state->getValue('purposeExternalIconWrapperClass'))
            ->set('purposeExternalIconType', $form_state->getValue('purposeExternalIconType'))
            ->set('purposeExternalIconPosition', $form_state->getValue('purposeExternalIconPosition'))
            ->set('purposeExternalIconClasses', $form_state->getValue('purposeExternalIconClasses'))
            ->save();
        parent::submitForm($form, $form_state);
    }

}
